@@ -25,9 +25,11 @@ class SwaggerEditor(object):
     _X_ANY_METHOD = "x-amazon-apigateway-any-method"
     _X_APIGW_REQUEST_VALIDATORS = "x-amazon-apigateway-request-validators"
     _X_APIGW_REQUEST_VALIDATOR = "x-amazon-apigateway-request-validator"
+    _X_ENDPOINT_CONFIG = "x-amazon-apigateway-endpoint-configuration"
     _CACHE_KEY_PARAMETERS = "cacheKeyParameters"
     # https://www.w3.org/Protocols/rfc2616/rfc2616-sec9.html
     _ALL_HTTP_METHODS = ["OPTIONS", "GET", "HEAD", "POST", "PUT", "DELETE", "PATCH"]
+    _EXCLUDED_PATHS_FIELDS = ["summary", "description", "parameters"]
     _POLICY_TYPE_IAM = "Iam"
     _POLICY_TYPE_IP = "Ip"
     _POLICY_TYPE_VPC = "Vpc"
@@ -110,6 +112,19 @@ class SwaggerEditor(object):
             return method[self._CONDITIONAL_IF][1:]
         return [method]
 
+    def add_disable_execute_api_endpoint_extension(self, disable_execute_api_endpoint):
+        """Add endpoint configuration to _X_APIGW_ENDPOINT_CONFIG in open api definition as extension
+        Following this guide:
+        https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-swagger-extensions-endpoint-configuration.html
+        :param boolean disable_execute_api_endpoint: Specifies whether clients can invoke your API by using the default execute-api endpoint.
+        """
+        if not self._doc.get(self._X_ENDPOINT_CONFIG):
+            self._doc[self._X_ENDPOINT_CONFIG] = {}
+
+        DISABLE_EXECUTE_API_ENDPOINT = "disableExecuteApiEndpoint"
+        set_disable_api_endpoint = {DISABLE_EXECUTE_API_ENDPOINT: disable_execute_api_endpoint}
+        self._doc[self._X_ENDPOINT_CONFIG].update(set_disable_api_endpoint)
+
     def has_integration(self, path, method):
         """
         Checks if an API Gateway integration is already present at the given path/method
@@ -527,8 +542,8 @@ class SwaggerEditor(object):
         for method_name, method in self.get_path(path).items():
             normalized_method_name = self._normalize_method_name(method_name)
 
-            # Excluding parameters section
-            if normalized_method_name == "parameters":
+            # Excluding non-method sections
+            if normalized_method_name in SwaggerEditor._EXCLUDED_PATHS_FIELDS:
                 continue
             if add_default_auth_to_preflight or normalized_method_name != "options":
                 normalized_method_name = self._normalize_method_name(method_name)
@@ -623,8 +638,8 @@ class SwaggerEditor(object):
         """
 
         for method_name, method in self.get_path(path).items():
-            # Excluding parameters section
-            if method_name == "parameters":
+            # Excluding non-method sections
+            if method_name in SwaggerEditor._EXCLUDED_PATHS_FIELDS:
                 continue
 
             # It is possible that the method could have two definitions in a Fn::If block.
@@ -902,7 +917,7 @@ class SwaggerEditor(object):
 
             self.definitions[model_name.lower()] = schema
 
-    def add_resource_policy(self, resource_policy, path, api_id, stage):
+    def add_resource_policy(self, resource_policy, path, stage):
         """
         Add resource policy definition to Swagger.
 
@@ -928,19 +943,19 @@ class SwaggerEditor(object):
         source_vpce_intrinsic_blacklist = resource_policy.get("IntrinsicVpceBlacklist")
 
         if aws_account_whitelist is not None:
-            resource_list = self._get_method_path_uri_list(path, api_id, stage)
+            resource_list = self._get_method_path_uri_list(path, stage)
             self._add_iam_resource_policy_for_method(aws_account_whitelist, "Allow", resource_list)
 
         if aws_account_blacklist is not None:
-            resource_list = self._get_method_path_uri_list(path, api_id, stage)
+            resource_list = self._get_method_path_uri_list(path, stage)
             self._add_iam_resource_policy_for_method(aws_account_blacklist, "Deny", resource_list)
 
         if ip_range_whitelist is not None:
-            resource_list = self._get_method_path_uri_list(path, api_id, stage)
+            resource_list = self._get_method_path_uri_list(path, stage)
             self._add_ip_resource_policy_for_method(ip_range_whitelist, "NotIpAddress", resource_list)
 
         if ip_range_blacklist is not None:
-            resource_list = self._get_method_path_uri_list(path, api_id, stage)
+            resource_list = self._get_method_path_uri_list(path, stage)
             self._add_ip_resource_policy_for_method(ip_range_blacklist, "IpAddress", resource_list)
 
         if not SwaggerEditor._validate_list_property_is_resolved(source_vpc_blacklist):
@@ -957,7 +972,7 @@ class SwaggerEditor(object):
             "IntrinsicVpcList": source_vpc_intrinsic_blacklist,
             "IntrinsicVpceList": source_vpce_intrinsic_blacklist,
         }
-        resource_list = self._get_method_path_uri_list(path, api_id, stage)
+        resource_list = self._get_method_path_uri_list(path, stage)
         self._add_vpc_resource_policy_for_method(blacklist_dict, "StringEquals", resource_list)
 
         if not SwaggerEditor._validate_list_property_is_resolved(source_vpc_whitelist):
@@ -1019,7 +1034,7 @@ class SwaggerEditor(object):
             statement.extend([policy_statement])
             self.resource_policy["Statement"] = statement
 
-    def _get_method_path_uri_list(self, path, api_id, stage):
+    def _get_method_path_uri_list(self, path, stage):
         """
         It turns out that APIGW doesn't like trailing slashes in paths (#665)
         and removes as a part of their behavior, but this isn't documented.
