@@ -1,4 +1,7 @@
 import copy
+from six import string_types
+
+from samtranslator.metrics.method_decorator import MetricsMethodWrapperSingleton
 from samtranslator.metrics.metrics import DummyMetricsPublisher, Metrics
 
 from samtranslator.feature_toggle.feature_toggle import (
@@ -27,6 +30,7 @@ from samtranslator.plugins.policies.policy_templates_plugin import PolicyTemplat
 from samtranslator.policy_template_processor.processor import PolicyTemplatesProcessor
 from samtranslator.sdk.parameter import SamParameterValues
 from samtranslator.translator.arn_generator import ArnGenerator
+from samtranslator.model.eventsources.push import Api
 
 
 class Translator:
@@ -45,6 +49,7 @@ class Translator:
         self.feature_toggle = None
         self.boto_session = boto_session
         self.metrics = metrics if metrics else Metrics("ServerlessTransform", DummyMetricsPublisher())
+        MetricsMethodWrapperSingleton.set_instance(self.metrics)
 
         if self.boto_session:
             ArnGenerator.BOTO_SESSION_REGION_NAME = self.boto_session.region_name
@@ -64,11 +69,8 @@ class Translator:
                     # adds to the function_names dict with key as the api_name and value as the function_name
                     if item.get("Type") == "Api" and item.get("Properties") and item.get("Properties").get("RestApiId"):
                         rest_api = item.get("Properties").get("RestApiId")
-                        if isinstance(rest_api, dict):
-                            api_name = item.get("Properties").get("RestApiId").get("Ref")
-                        else:
-                            api_name = item.get("Properties").get("RestApiId")
-                        if api_name:
+                        api_name = Api.get_rest_api_id_string(rest_api)
+                        if isinstance(api_name, string_types):
                             resource_dict_copy = copy.deepcopy(resource_dict)
                             function_name = intrinsics_resolver.resolve_parameter_refs(
                                 resource_dict_copy.get("Properties").get("FunctionName")
